:mod:`cf.backends.dbapi2helper` -- Helper classes for DB-API2 connections
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: cf.backends.dbapi2helper
   :members:
   :synopsis: Helper classes for DB-API2 connections
